;; Generated package description from gtags-mode.el  -*- no-byte-compile: t -*-
(define-package "gtags-mode" "1.1.0.20240313.5421" "GNU Global integration with xref, project and imenu." '((emacs "28")) :commit "4e0a03dc42dacb0d03c82bce479f765ca2efca52" :keywords '("xref" "project" "imenu" "gtags" "global") :url "https://github.com/Ergus/gtags-mode")
